@@ -47,7 +47,8 @@ __all__ = ['get_session', 'set_session', 'get_session_value', 'is_autocast_enabl
 # workarounds is necessary
 import six
 from trident import context
-
+import warnings
+warnings.simplefilter("ignore")
 _int = builtins.int
 _float = builtins.float
 _bool = builtins.bool
@@ -299,10 +300,12 @@ def adaptive_format(num: numbers.Number, prev_value: Union[numbers.Number, Itera
             return '{0:.3%}'.format(num)
         elif len(prev_value) > 0:
             digit = int(np.array([builtins.abs(builtins.min(math.log10(builtins.abs(s)), 0)) + 3 if s != 0 else 0 for s in prev_value]).mean())
-            if digit > 4:
+            if digit > 5:
                 return '{0:{1}}'.format(num, '.3e')
-            elif digit < 2:
+            elif digit < 3:
                 return '{0:{1}}'.format(num, '.3f')
+            elif digit <= 5:
+                return '{0:{1}}'.format(num, '.4f')
             else:
                 return '{0:.{1}%}'.format(num, digit)
     elif name is not None and len(name) >= 3 and any([name.lower() in s.lower() for s in percentage_name]):
