@@ -22,7 +22,7 @@ from trident.data.transform import VisionTransform
 
 __all__ = ['Resize', 'ShortestEdgeResize', 'Rescale', 'RandomCrop', 'RandomRescaleCrop', 'RandomCenterCrop', 'RandomMultiScaleImage', 'RandomTransform', 'RandomTransformAffine',
            'AdjustBrightness', 'AdjustContrast', 'AdjustSaturation', 'AddNoise', 'AdjustHue', 'RandomAdjustHue', 'RandomAdjustBrightness', 'RandomAdjustContrast',
-           'RandomAdjustSaturation',
+           'RandomAdjustSaturation','AutoLevel',
            'Normalize', 'Unnormalize', 'CLAHE', 'Lighting', 'HorizontalFlip', 'RandomMirror', 'AdjustGamma', 'RandomBlur', 'RandomAdjustGamma', 'Blur', 'InvertColor',
            'RandomInvertColor', 'GrayScale', 'RandomGrayScale',
            'ImageDilation', 'ImageErosion', 'ErosionThenDilation', 'DilationThenErosion', 'AdaptiveBinarization', 'SaltPepperNoise', 'RandomErasing', 'ToRGB', 'ImageMosaic']
@@ -325,7 +325,7 @@ class Rescale(VisionTransform):
         h, w, _ = mask.shape
         mask_dtype = mask.dtype
         mask = mask.astype(np.float32)
-        mask = cv2.resize(mask, (tw, th), cv2.INTER_NEAREST)
+        mask = cv2.resize(mask,self.output_size , cv2.INTER_NEAREST)
         mask = mask.astype(mask_dtype)
         return mask
 
@@ -1572,7 +1572,7 @@ class CLAHE(VisionTransform):
         return mask
 
 
-class AutoLeveling(VisionTransform):
+class AutoLevel(VisionTransform):
 
     def __init__(self, name='autoleveling', **kwargs):
         super().__init__(name)
@@ -1583,9 +1583,12 @@ class AutoLeveling(VisionTransform):
     def _apply_image(self, image, spec: TensorSpec):
         minv = np.percentile(image, 5)
         maxv = np.percentile(image, 95)
-        if maxv - minv < 40:
+        if minv == maxv:
+            return image
+        elif maxv - minv < 40:
             minv = image.min()
             maxv = image.max()
+
         image = np.clip((image - minv) * (255.0 / (maxv - minv)), 0, 255)
         return image.astype(np.float32)
 
